==> mcu_plus_sdk_am64x_08_00_00_21_docs_only.tar.xz: mcu_plus_sdk_am64x_08_00_00_21_docs_only/docs/api_guide_am64x/group__BOARD__EEPROM__MODULE.js <==
var group__BOARD__EEPROM__MODULE =
[
    [ "EEPROM_Params", "structEEPROM__Params.html", [
      [ "driverInstance", "structEEPROM__Params.html#a424ab348295254ac373772bf7a92b23f", null ],
      [ "i2cAddress", "structEEPROM__Params.html#a6818a21fac4c1b8750145e71dc48a8ea", null ]
    ] ],
    [ "EEPROM_Fxns", "structEEPROM__Fxns.html", [
      [ "openFxn", "structEEPROM__Fxns.html#a8b49c618fccd93f4a131d19f62779519", null ],
      [ "closeFxn", "structEEPROM__Fxns.html#a1045db6d6717d6538363052e667e01c4", null ],
      [ "readFxn", "structEEPROM__Fxns.html#a080878c59f5ecf14cbbe62a3b2cff65c", null ],
      [ "writeFxn", "structEEPROM__Fxns.html#a2be49cda279b71221aa7298898d929dd", null ]
    ] ],
    [ "EEPROM_Attrs", "structEEPROM__Attrs.html", [
      [ "size", "structEEPROM__Attrs.html#ac6ffb051bb5551f2ab97c93278968d6f", null ],
      [ "pageCount", "structEEPROM__Attrs.html#ab8d21b11713ce8bf7157f7a76d2cf7d1", null ],
      [ "pageSize", "structEEPROM__Attrs.html#ab5409dc32ab52ad52ace4a745642d97f", null ]
    ] ],
    [ "EEPROM_Config", "structEEPROM__Config.html", [
      [ "attrs", "structEEPROM__Config.html#a6ab9b742abfd9e214a098341d0178a0a", null ],
      [ "fxns", "structEEPROM__Config.html#acb9dae722b7badaa917cb1907f171b2a", null ],
      [ "object", "structEEPROM__Config.html#ae7c4fc69b2b0489389b25852d7e24faa", null ]
    ] ],
    [ "EEPROM_Object", "structEEPROM__Object.html", [
      [ "i2cHandle", "structEEPROM__Object.html#a9ad7ea23393a3ae5fbb3cbfcef4845d3", null ],
      [ "driverInstance", "structEEPROM__Object.html#ad8d1bfda8d1ccb9c3aa494860b58e3d4", null ],
      [ "i2cAddress", "structEEPROM__Object.html#a648518ecd521d973da0597593c92c449", null ],
      [ "pageWrBuf", "structEEPROM__Object.html#a94bba1e10bab6c922ab5450a0ed8cce1", null ],
      [ "lock", "structEEPROM__Object.html#aafbb57c7343e8181e9635eb1d6e25676", null ],
      [ "lockObj", "structEEPROM__Object.html#a8f76e10120ddf201289d110e6bf0f40c", null ]
    ] ],
    [ "EEPROM_PAGE_SIZE", "group__BOARD__EEPROM__MODULE.html#gaddfda15f5f3ec6f8f325f48be50c548a", null ],
    [ "EEPROM_WR_BUF_SIZE", "group__BOARD__EEPROM__MODULE.html#ga31a1b76056200498ae6cfee77e4e795d", null ],
    [ "EEPROM_Handle", "group__BOARD__EEPROM__MODULE.html#ga7c98365db580ac419d1d79f9092b6600", null ],
    [ "EEPROM_Config", "group__BOARD__EEPROM__MODULE.html#ga240008bde333819fa5827f02f84ff77d", null ],
    [ "EEPROM_Params", "group__BOARD__EEPROM__MODULE.html#gafe920cb893730d38770242bb02950ae7", null ],
    [ "EEPROM_OpenFxn", "group__BOARD__EEPROM__MODULE.html#ga8afcc68023cce83655bd0b3b9b6a0084", null ],
    [ "EEPROM_CloseFxn", "group__BOARD__EEPROM__MODULE.html#gae2a8ad778c9068980d732042ccf48c92", null ],
    [ "EEPROM_ReadFxn", "group__BOARD__EEPROM__MODULE.html#ga400e6f4c4f818cfd518bb9c0bdadf71e", null ],
    [ "EEPROM_WriteFxn", "group__BOARD__EEPROM__MODULE.html#ga217fa89d4abbc7fbd48c6340e4b822b6", null ],
    [ "EEPROM_Params_init", "group__BOARD__EEPROM__MODULE.html#ga6bca7796076113af676bf29de97a1a34", null ],
    [ "EEPROM_open", "group__BOARD__EEPROM__MODULE.html#ga2de27afd8e7c5139d39edd805e26dbc3", null ],
    [ "EEPROM_close", "group__BOARD__EEPROM__MODULE.html#gaf0f012e94a2dde736755b2ab33bfcd56", null ],
    [ "EEPROM_read", "group__BOARD__EEPROM__MODULE.html#ga68ee21f3536d1285b710553023a27b2d", null ],
    [ "EEPROM_write", "group__BOARD__EEPROM__MODULE.html#ga0b9c545f8bb83dd9a6e11858ffb3bb42", null ],
    [ "EEPROM_getAttrs", "group__BOARD__EEPROM__MODULE.html#ga62c846e63c8d0f2820674ed1695032d7", null ]
];

==> mcu_plus_sdk_am64x_08_01_00_36_docs_only.tar.xz: mcu_plus_sdk_am64x_08_01_00_36_docs_only/docs/api_guide_am64x/group__BOARD__EEPROM__MODULE.js <==
var group__BOARD__EEPROM__MODULE =
[
    [ "EEPROM_Params", "structEEPROM__Params__s.html", [
      [ "driverInstance", "structEEPROM__Params__s.html#a424ab348295254ac373772bf7a92b23f", null ],
      [ "i2cAddress", "structEEPROM__Params__s.html#a6818a21fac4c1b8750145e71dc48a8ea", null ]
    ] ],
    [ "EEPROM_Fxns", "structEEPROM__Fxns.html", [
      [ "openFxn", "structEEPROM__Fxns.html#a8b49c618fccd93f4a131d19f62779519", null ],
      [ "closeFxn", "structEEPROM__Fxns.html#a1045db6d6717d6538363052e667e01c4", null ],
      [ "readFxn", "structEEPROM__Fxns.html#a080878c59f5ecf14cbbe62a3b2cff65c", null ],
      [ "writeFxn", "structEEPROM__Fxns.html#a2be49cda279b71221aa7298898d929dd", null ]
    ] ],
    [ "EEPROM_Attrs", "structEEPROM__Attrs.html", [
      [ "size", "structEEPROM__Attrs.html#ac6ffb051bb5551f2ab97c93278968d6f", null ],
      [ "pageCount", "structEEPROM__Attrs.html#ab8d21b11713ce8bf7157f7a76d2cf7d1", null ],
      [ "pageSize", "structEEPROM__Attrs.html#ab5409dc32ab52ad52ace4a745642d97f", null ]
    ] ],
    [ "EEPROM_Config", "structEEPROM__Config__s.html", [
      [ "attrs", "structEEPROM__Config__s.html#a6ab9b742abfd9e214a098341d0178a0a", null ],
      [ "fxns", "structEEPROM__Config__s.html#acb9dae722b7badaa917cb1907f171b2a", null ],
      [ "object", "structEEPROM__Config__s.html#ae7c4fc69b2b0489389b25852d7e24faa", null ]
    ] ],
    [ "EEPROM_Object", "structEEPROM__Object.html", [
      [ "i2cHandle", "structEEPROM__Object.html#a9ad7ea23393a3ae5fbb3cbfcef4845d3", null ],
      [ "driverInstance", "structEEPROM__Object.html#ad8d1bfda8d1ccb9c3aa494860b58e3d4", null ],
      [ "i2cAddress", "structEEPROM__Object.html#a648518ecd521d973da0597593c92c449", null ],
      [ "pageWrBuf", "structEEPROM__Object.html#a94bba1e10bab6c922ab5450a0ed8cce1", null ],
      [ "lock", "structEEPROM__Object.html#aafbb57c7343e8181e9635eb1d6e25676", null ],
      [ "lockObj", "structEEPROM__Object.html#a8f76e10120ddf201289d110e6bf0f40c", null ]
    ] ],
    [ "EEPROM_PAGE_SIZE", "group__BOARD__EEPROM__MODULE.html#gaddfda15f5f3ec6f8f325f48be50c548a", null ],
    [ "EEPROM_WR_BUF_SIZE", "group__BOARD__EEPROM__MODULE.html#ga31a1b76056200498ae6cfee77e4e795d", null ],
    [ "EEPROM_Handle", "group__BOARD__EEPROM__MODULE.html#ga7c98365db580ac419d1d79f9092b6600", null ],
    [ "EEPROM_OpenFxn", "group__BOARD__EEPROM__MODULE.html#ga8afcc68023cce83655bd0b3b9b6a0084", null ],
    [ "EEPROM_CloseFxn", "group__BOARD__EEPROM__MODULE.html#gae2a8ad778c9068980d732042ccf48c92", null ],
    [ "EEPROM_ReadFxn", "group__BOARD__EEPROM__MODULE.html#ga400e6f4c4f818cfd518bb9c0bdadf71e", null ],
    [ "EEPROM_WriteFxn", "group__BOARD__EEPROM__MODULE.html#ga217fa89d4abbc7fbd48c6340e4b822b6", null ],
    [ "EEPROM_Params_init", "group__BOARD__EEPROM__MODULE.html#ga6bca7796076113af676bf29de97a1a34", null ],
    [ "EEPROM_open", "group__BOARD__EEPROM__MODULE.html#ga2de27afd8e7c5139d39edd805e26dbc3", null ],
    [ "EEPROM_close", "group__BOARD__EEPROM__MODULE.html#gaf0f012e94a2dde736755b2ab33bfcd56", null ],
    [ "EEPROM_read", "group__BOARD__EEPROM__MODULE.html#ga68ee21f3536d1285b710553023a27b2d", null ],
    [ "EEPROM_write", "group__BOARD__EEPROM__MODULE.html#ga0b9c545f8bb83dd9a6e11858ffb3bb42", null ],
    [ "EEPROM_getAttrs", "group__BOARD__EEPROM__MODULE.html#ga62c846e63c8d0f2820674ed1695032d7", null ]
];
